package App::ShellCompleter::perlbrew;

our $DATE = '2016-04-30'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Shell completion for perlbrew

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ShellCompleter::perlbrew - Shell completion for perlbrew

=head1 VERSION

This document describes version 0.003 of App::ShellCompleter::perlbrew (from Perl distribution App-ShellCompleter-perlbrew), released on 2016-04-30.

=head1 SYNOPSIS

See L<_perlbrew> included in this distribution.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-ShellCompleter-perlbrew>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-ShellCompleter-perlbrew>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ShellCompleter-perlbrew>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::perlbrew>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
